import java.util.Scanner;

public class Calculator {
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);

        while (true) {
            System.out.print("Enter a mathematical formula or 'quit' for exit: ");
            String input = scanner.nextLine();

            if (input.equalsIgnoreCase("quit")) {
                System.out.println("The application has shut down.");
                break;
            }

            try {
                double result = evaluateExpression(input);
                System.out.println("The result is" + result + ".");
            } catch (Exception ex) {
                System.out.println("False: " + ex.getMessage());
            }
        }
    }

    private static double evaluateExpression(String expression) {
        return new Object() {
            int pos = -1, ch;

            void nextChar() {
                ch = (++pos < expression.length()) ? expression.charAt(pos) : -1;
            }

            boolean isDigit(int c) {
                return c >= '0' && c <= '9';
            }

            double parse() {
                nextChar();
                double x = parseExpression();
                if (ch != -1)
                    throw new RuntimeException("Invalid formula");
                return x;
            }

            double parseExpression() {
                double x = parseTerm();
                for (;;) {
                    if (ch == '+') {
                        nextChar();
                        x += parseTerm();
                    } else if (ch == '-') {
                        nextChar();
                        x -= parseTerm();
                    } else
                        return x;
                }
            }

            double parseTerm() {
                double x = parseFactor();
                for (;;) {
                    if (ch == '*') {
                        nextChar();
                        x *= parseFactor();
                    } else if (ch == '/') {
                        nextChar();
                        x /= parseFactor();
                    } else
                        return x;
                }
            }

            double parseFactor() {
                if (ch == '(') {
                    nextChar();
                    double x = parseExpression();
                    if (ch != ')')
                        throw new RuntimeException("Closing with expected");
                    nextChar();
                    return x;
                }
                if (ch == 'x') {
                    nextChar();
                    return 42;
                }
                int startPos = pos;
                while ((ch >= '0' && ch <= '9') || ch == '.')
                    nextChar();
                if (startPos == pos)
                    throw new RuntimeException("Number is expected");
                return Double.parseDouble(expression.substring(startPos, pos));
            }
        }.parse();
    }
}
